Work environment (site related) | OiRA

Help

1. Подготовка
2. Включване
3. Определяне + Оценяване
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
   2. Ω Добавени рискове (от Вас)
   - Без отговор
   - Отложено разглеждане
   - Правилно
   - Внимание
4. План за действие
5. Доклад
6. Статус 0%

# Work environment (site related)

It's all about security

Accident statistics show that risks like slips, trips and falls, getting stuck, … are very frequent in the private security services sector.

It is therefore important to pay attention to the physical environment of the client’s premises (e.g. the retail store): floors, passageways, stairs, facilities, lighting, climate, electricity, …

IMPORTANT. These risks are related to the activities and installations of the client. It is therefore important that the private security services company and the client company cooperate to tackle these risks and guarantee the health and safety of the private security guards. This implies that the private security services company and the private security guards should be informed based on the client’s risk assessments and be involved in drawing conclusions and designing preventive measures.

The next screens let you check whether the necessary measures are in place on this site.

Scroll to top
Back

## 2014-01-02-work-environment-site-related.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More